@@ -43,6 +43,7 @@ class NetcashTest(TestCase):
             'p4': 100,
         })
         reference = str(form.order.pk)
+        self.assertEqual(form.order.suspicious, None)
 
         self.assertFalse(data_handler.called)
 
@@ -65,6 +66,7 @@ class NetcashTest(TestCase):
         self.assertEqual(order.RETC, '123')
         self.assertEqual(order.gateway, self.gateway)
         self.assertEqual(order.request_ip, '127.0.0.1')
+        self.assertEqual(order.suspicious, False)
 
         self.assertTrue(data_handler.called)
         self.assertEqual(data_handler.order, order)
